from django.urls import reverse
from django.contrib.auth.models import User
from rest_framework import viewsets
from rest_framework import generics
from rest_framework import permissions
from rest_framework import status
from rest_framework.response import Response
from guardian.shortcuts import get_objects_for_user

from uhepp_vault.models import Plot, Collection
from .serializers import PlotSerializer, CollectionSerializer, \
                         CollectionListSerializer
from .permissions import FullObjectPermissions

class PlotCreate(generics.CreateAPIView):
    """Create a model instance with Location header"""
    queryset = Plot.objects
    serializer_class = PlotSerializer
    permission_classes = []

    def get_success_headers(self, obj):
        uuid = obj.pop("uuid")
        api_url = reverse('plot-detail', args=[uuid])
        api_url = self.request.build_absolute_uri(api_url)

        ui_url = reverse('uhepp_vault:plot-detail', args=[uuid])
        ui_url = self.request.build_absolute_uri(ui_url)
        return {
            'Location': api_url,
            'Link': f'<{ui_url}>; rel="ui"',
            'X-Resource-UUID': uuid,
        }
    
class CollectionList(generics.ListAPIView):
    serializer_class = CollectionListSerializer
    permission_classes = []

    def get_queryset(self):
        return get_objects_for_user(self.request.user,
                                    'uhepp_vault.discover_collection',
                                    Collection)

class CollectionDetail(generics.RetrieveAPIView):
    queryset = Collection.objects
    serializer_class = CollectionSerializer
    permission_classes = [FullObjectPermissions]

class PlotDetail(generics.RetrieveAPIView):
    queryset = Plot.objects
    serializer_class = PlotSerializer
    permission_classes = [FullObjectPermissions]
