from django.db import models
from django.contrib.auth.models import User, Group
from django.utils.translation import gettext_lazy as _
from uhepp_api.models import Token
import uuid

class Collection(models.Model):
    uuid = models.UUIDField(default=uuid.uuid4, primary_key=True)
    user = models.ForeignKey(User, on_delete=models.CASCADE,
                             related_name='collections')
    slug = models.SlugField(_("Collection URL slug"))
    title = models.CharField(_("Collection title"), max_length=100)
    description = models.TextField(_("Collection description"),
                                   null=True, blank=True)
    class Meta:
        permissions = (
            ('discover_collection', 'Discover collection'),
        )

    def __str__(self):
        return f"{self.user}: {self.title}"

class Plot(models.Model):
    """Database record of a uhepp compliant plot"""
    uuid = models.UUIDField(primary_key=True, default=uuid.uuid4)
    data = models.JSONField()
    collection = models.ForeignKey(Collection, on_delete=models.CASCADE,
                                   related_name='plots')

    def __str__(self):
        metadata = self.data.get("metadata", {})
        return metadata.get("filename", self.uuid)

class Profile(models.Model):
    """User profile"""
    user = models.OneToOneField(User,
                                on_delete=models.CASCADE,
                                primary_key=True)
    cern_upn = models.CharField(_("User Principal Name"), max_length=100,
                                  unique=True)

    cern_uid = models.IntegerField(_("CERN User ID"), null=True, blank=True)
    home_institute = models.CharField(_("Home Institute"), max_length=100,
                                      null=True, blank=True)
    cern_person_id = models.IntegerField(_("CERN Person ID"), null=True,
                                          blank=True)



    def __str__(self):
        return self.cern_upn

class Collaboration(models.Model):
    name = models.CharField(_("Collaboration name"), max_length=32)
    cern_role = models.CharField(_("CERN access role"), max_length=32)
    perm_group = models.OneToOneField(Group,
                                      on_delete=models.CASCADE,
                                      related_name="collaboration",
                                      primary_key=True)

    def __str__(self):
        return self.name
